The :mod:`guidata` package requires the following Python modules:

.. list-table::
    :header-rows: 1
    :align: left

    * - Name
      - Version
      - Summary
    * - Python
      - >=3.8, <4
      - Python programming language
    * - h5py
      - >=3.0
      - Read and write HDF5 files from Python
    * - NumPy
      - >=1.21
      - Fundamental package for array computing in Python
    * - QtPy
      - >=1.9
      - Provides an abstraction layer on top of the various Qt bindings (PyQt5/6 and PySide2/6).
    * - requests
      - 
      - Python HTTP for Humans.
    * - tomli
      - 
      - A lil' TOML parser
    * - PyQt5
      - >=5.11
      - Python bindings for the Qt cross platform application toolkit

Optional modules for development:

.. list-table::
    :header-rows: 1
    :align: left

    * - Name
      - Version
      - Summary
    * - ruff
      - 
      - An extremely fast Python linter and code formatter, written in Rust.
    * - pylint
      - 
      - python code static checker
    * - Coverage
      - 
      - Code coverage measurement for Python

Optional modules for building the documentation:

.. list-table::
    :header-rows: 1
    :align: left

    * - Name
      - Version
      - Summary
    * - PyQt5
      - 
      - Python bindings for the Qt cross platform application toolkit
    * - pillow
      - 
      - Python Imaging Library (Fork)
    * - pandas
      - 
      - Powerful data structures for data analysis, time series, and statistics
    * - sphinx
      - >6
      - Python documentation generator
    * - myst_parser
      - 
      - An extended [CommonMark](https://spec.commonmark.org/) compliant parser,
    * - sphinx-copybutton
      - 
      - Add a copy button to each of your code cells.
    * - sphinx_qt_documentation
      - 
      - Plugin for proper resolve intersphinx references for Qt elements
    * - python-docs-theme
      - 
      - The Sphinx theme for the CPython docs and related projects

Optional modules for running test suite:

.. list-table::
    :header-rows: 1
    :align: left

    * - Name
      - Version
      - Summary
    * - pytest
      - 
      - pytest: simple powerful testing with Python
    * - pytest-xvfb
      - 
      - A pytest plugin to run Xvfb (or Xephyr/Xvnc) for tests.